# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.identity._verification_report_list_params import (
    VerificationReportListParams as VerificationReportListParams,
)
from stripe.params.identity._verification_report_retrieve_params import (
    VerificationReportRetrieveParams as VerificationReportRetrieveParams,
)
from stripe.params.identity._verification_session_cancel_params import (
    VerificationSessionCancelParams as VerificationSessionCancelParams,
)
from stripe.params.identity._verification_session_create_params import (
    VerificationSessionCreateParams as VerificationSessionCreateParams,
)
from stripe.params.identity._verification_session_list_params import (
    VerificationSessionListParams as VerificationSessionListParams,
)
from stripe.params.identity._verification_session_modify_params import (
    VerificationSessionModifyParams as VerificationSessionModifyParams,
)
from stripe.params.identity._verification_session_redact_params import (
    VerificationSessionRedactParams as VerificationSessionRedactParams,
)
from stripe.params.identity._verification_session_retrieve_params import (
    VerificationSessionRetrieveParams as VerificationSessionRetrieveParams,
)
from stripe.params.identity._verification_session_update_params import (
    VerificationSessionUpdateParams as VerificationSessionUpdateParams,
)
