# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.terminal._configuration_create_params import (
    ConfigurationCreateParams as ConfigurationCreateParams,
)
from stripe.params.terminal._configuration_delete_params import (
    ConfigurationDeleteParams as ConfigurationDeleteParams,
)
from stripe.params.terminal._configuration_list_params import (
    ConfigurationListParams as ConfigurationListParams,
)
from stripe.params.terminal._configuration_modify_params import (
    ConfigurationModifyParams as ConfigurationModifyParams,
)
from stripe.params.terminal._configuration_retrieve_params import (
    ConfigurationRetrieveParams as ConfigurationRetrieveParams,
)
from stripe.params.terminal._configuration_update_params import (
    ConfigurationUpdateParams as ConfigurationUpdateParams,
)
from stripe.params.terminal._connection_token_create_params import (
    ConnectionTokenCreateParams as ConnectionTokenCreateParams,
)
from stripe.params.terminal._location_create_params import (
    LocationCreateParams as LocationCreateParams,
)
from stripe.params.terminal._location_delete_params import (
    LocationDeleteParams as LocationDeleteParams,
)
from stripe.params.terminal._location_list_params import (
    LocationListParams as LocationListParams,
)
from stripe.params.terminal._location_modify_params import (
    LocationModifyParams as LocationModifyParams,
)
from stripe.params.terminal._location_retrieve_params import (
    LocationRetrieveParams as LocationRetrieveParams,
)
from stripe.params.terminal._location_update_params import (
    LocationUpdateParams as LocationUpdateParams,
)
from stripe.params.terminal._reader_cancel_action_params import (
    ReaderCancelActionParams as ReaderCancelActionParams,
)
from stripe.params.terminal._reader_collect_inputs_params import (
    ReaderCollectInputsParams as ReaderCollectInputsParams,
)
from stripe.params.terminal._reader_collect_payment_method_params import (
    ReaderCollectPaymentMethodParams as ReaderCollectPaymentMethodParams,
)
from stripe.params.terminal._reader_confirm_payment_intent_params import (
    ReaderConfirmPaymentIntentParams as ReaderConfirmPaymentIntentParams,
)
from stripe.params.terminal._reader_create_params import (
    ReaderCreateParams as ReaderCreateParams,
)
from stripe.params.terminal._reader_delete_params import (
    ReaderDeleteParams as ReaderDeleteParams,
)
from stripe.params.terminal._reader_list_params import (
    ReaderListParams as ReaderListParams,
)
from stripe.params.terminal._reader_modify_params import (
    ReaderModifyParams as ReaderModifyParams,
)
from stripe.params.terminal._reader_present_payment_method_params import (
    ReaderPresentPaymentMethodParams as ReaderPresentPaymentMethodParams,
)
from stripe.params.terminal._reader_process_payment_intent_params import (
    ReaderProcessPaymentIntentParams as ReaderProcessPaymentIntentParams,
)
from stripe.params.terminal._reader_process_setup_intent_params import (
    ReaderProcessSetupIntentParams as ReaderProcessSetupIntentParams,
)
from stripe.params.terminal._reader_refund_payment_params import (
    ReaderRefundPaymentParams as ReaderRefundPaymentParams,
)
from stripe.params.terminal._reader_retrieve_params import (
    ReaderRetrieveParams as ReaderRetrieveParams,
)
from stripe.params.terminal._reader_set_reader_display_params import (
    ReaderSetReaderDisplayParams as ReaderSetReaderDisplayParams,
)
from stripe.params.terminal._reader_succeed_input_collection_params import (
    ReaderSucceedInputCollectionParams as ReaderSucceedInputCollectionParams,
)
from stripe.params.terminal._reader_timeout_input_collection_params import (
    ReaderTimeoutInputCollectionParams as ReaderTimeoutInputCollectionParams,
)
from stripe.params.terminal._reader_update_params import (
    ReaderUpdateParams as ReaderUpdateParams,
)
