# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.params.tax._calculation_create_params import (
    CalculationCreateParams as CalculationCreateParams,
)
from stripe.params.tax._calculation_line_item_list_params import (
    CalculationLineItemListParams as CalculationLineItemListParams,
)
from stripe.params.tax._calculation_list_line_items_params import (
    CalculationListLineItemsParams as CalculationListLineItemsParams,
)
from stripe.params.tax._calculation_retrieve_params import (
    CalculationRetrieveParams as CalculationRetrieveParams,
)
from stripe.params.tax._registration_create_params import (
    RegistrationCreateParams as RegistrationCreateParams,
)
from stripe.params.tax._registration_list_params import (
    RegistrationListParams as RegistrationListParams,
)
from stripe.params.tax._registration_modify_params import (
    RegistrationModifyParams as RegistrationModifyParams,
)
from stripe.params.tax._registration_retrieve_params import (
    RegistrationRetrieveParams as RegistrationRetrieveParams,
)
from stripe.params.tax._registration_update_params import (
    RegistrationUpdateParams as RegistrationUpdateParams,
)
from stripe.params.tax._settings_modify_params import (
    SettingsModifyParams as SettingsModifyParams,
)
from stripe.params.tax._settings_retrieve_params import (
    SettingsRetrieveParams as SettingsRetrieveParams,
)
from stripe.params.tax._settings_update_params import (
    SettingsUpdateParams as SettingsUpdateParams,
)
from stripe.params.tax._transaction_create_from_calculation_params import (
    TransactionCreateFromCalculationParams as TransactionCreateFromCalculationParams,
)
from stripe.params.tax._transaction_create_reversal_params import (
    TransactionCreateReversalParams as TransactionCreateReversalParams,
)
from stripe.params.tax._transaction_line_item_list_params import (
    TransactionLineItemListParams as TransactionLineItemListParams,
)
from stripe.params.tax._transaction_list_line_items_params import (
    TransactionListLineItemsParams as TransactionListLineItemsParams,
)
from stripe.params.tax._transaction_retrieve_params import (
    TransactionRetrieveParams as TransactionRetrieveParams,
)
